@@ -1,13 +1,13 @@
 
-// $Id: sjis_jsky.c,v 1.3 2002/10/30 01:12:21 hio Exp $
+/* $Id: sjis_jsky.c,v 1.4 2002/10/31 11:08:50 hio Exp $ */
 
 #include "Japanese.h"
 #include <stdio.h>
 
-#define ECHO_EJ2U(arg) //fprintf arg
-#define ON_EJ2U(cmd) //cmd
-#define ECHO_U2EJ(arg) //fprintf arg
-#define ON_U2EJ(cmd) //cmd
+#define ECHO_EJ2U(arg) /*fprintf arg */
+#define ON_EJ2U(cmd) /*cmd */
+#define ECHO_U2EJ(arg) /*fprintf arg */
+#define ON_U2EJ(cmd) /*cmd */
 
 #ifndef __cplusplus
 #undef bool
@@ -45,22 +45,22 @@ xs_sjis_jsky1_utf8(SV* sv_str)
   {
     const unsigned char* ptr;
     if( src[0]<0x80 )
-    { // ASCII
+    { /* ASCII */
       const unsigned char* begin;
       int j1;
       
-      //fprintf(stderr,"ascii: %02x\n",src[0]);
-      if( src[0]!='\e' || src+2>=src_end || src[1]!='$' )
-      { // ʸʤ
+      /*fprintf(stderr,"ascii: %02x\n",src[0]); */
+      if( src[0]!='\x1b' || src+2>=src_end || src[1]!='$' )
+      { /* ʸʤ */
 	SV_Buf_append_ch(&result,*src);
 	++src;
 	continue;
       }
-      //fprint(stderr,"detect j-sky emoji-start escape\n");
-      // E_JSKY_1
+      /*fprint(stderr,"detect j-sky emoji-start escape\n"); */
+      /* E_JSKY_1 */
       if( src[2]!='E' && src[2]!='F' && src[2]!='G' )
       {
-	//fprintf(stderr,"first char is invalid");
+	/*fprintf(stderr,"first char is invalid"); */
 	SV_Buf_append_ch(&result,*src);
 	++src;
 	continue;
@@ -68,7 +68,7 @@ xs_sjis_jsky1_utf8(SV* sv_str)
 
       begin = src;
       src += 3;
-      // E_JSKY_2
+      /* E_JSKY_2 */
       while( src+1<src_end )
       {
 	if( '!'<=src[0] && src[0]<='z' )
@@ -80,7 +80,7 @@ xs_sjis_jsky1_utf8(SV* sv_str)
       }
       if( src[0]!=0x0f )
       {
-	//fprintf(stderr,"invalid\n");
+	/*fprintf(stderr,"invalid\n"); */
 	src = begin;
 	SV_Buf_append_ch(&result,*src);
 	++src;
@@ -90,50 +90,50 @@ xs_sjis_jsky1_utf8(SV* sv_str)
       j1 = (begin[2]-'E')<<8;
       for( ptr = begin+3; ptr<src-1; ++ptr )
       {
-	//fprintf(stderr," <%c%c:%04x>\n",begin[2],*ptr,j1+*ptr);
-	//fprintf(stderr,"   => %04x\n",g_ej2u1_table[j1+*ptr]);
+	/*fprintf(stderr," <%c%c:%04x>\n",begin[2],*ptr,j1+*ptr); */
+	/*fprintf(stderr,"   => %04x\n",g_ej2u1_table[j1+*ptr]); */
 	const unsigned char* str = (unsigned char*)&g_ej2u1_table[j1+*ptr];
-	//fprintf(stderr,"   len: %d\n",str[3]?4:strlen((char*)str));
+	/*fprintf(stderr,"   len: %d\n",str[3]?4:strlen((char*)str)); */
 	SV_Buf_append_str(&result,str,str[3]?4:strlen((char*)str));
       }
-      //fprintf(stderr,"j-sky string done.\n");
+      /*fprintf(stderr,"j-sky string done.\n"); */
       continue;
     }else if( 0xa1<=src[0] && src[0]<=0xdf )
-    { // Ⱦѥ
-      //fprintf(stderr,"kana": %02x\n",src[0]);
+    { /* Ⱦѥ */
+      /*fprintf(stderr,"kana": %02x\n",src[0]); */
       ptr = (unsigned char*)&g_s2u_table[src[0]];
       ++src;
     }else if( ((0x81<=src[0] && src[0]<=0x9f) || (0xe0<=src[0] && src[0]<=0xfc) )
 	      && (0x40<=src[1] && src[1]<=0xfc && src[1]!=0x7f) )
-    { // 2Хʸ
+    { /* 2Хʸ */
       register const unsigned short sjis = ntohs(*(unsigned short*)src);
-      //fprintf(stderr,"sjis: %04x\n",sjis);
+      /*fprintf(stderr,"sjis: %04x\n",sjis); */
       ptr = (unsigned char*)&g_s2u_table[sjis];
       src += 2;
     }else
-    { // 
-      //fprintf(stderr,"unknown: %02x\n",src[0]);
+    { /*  */
+      /*fprintf(stderr,"unknown: %02x\n",src[0]); */
       SV_Buf_append_ch(&result,'?');
       ++src;
       continue;
     }
 
-    //fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]);
+    /*fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]); */
     if( ptr[3] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",4);
+      /*fprintf(stderr,"utf8-len: [%d]\n",4); */
       SV_Buf_append_ch4(&result,*(int*)ptr);
     }else if( ptr[2] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",3);
+      /*fprintf(stderr,"utf8-len: [%d]\n",3); */
       SV_Buf_append_ch3(&result,*(int*)ptr);
     }else if( ptr[1] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",2);
+      /*fprintf(stderr,"utf8-len: [%d]\n",2); */
       SV_Buf_append_ch2(&result,*(short*)ptr);
     }else
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",1);
+      /*fprintf(stderr,"utf8-len: [%d]\n",1); */
       SV_Buf_append_ch(&result,*ptr);
     }
   }
@@ -173,21 +173,21 @@ xs_sjis_jsky2_utf8(SV* sv_str)
   {
     const unsigned char* ptr;
     if( src[0]<0x80 )
-    { // ASCII
+    { /* ASCII */
       int j1;
       unsigned long const* table;
       const unsigned char* begin;
       const unsigned char* ptr;
       
-      //fprintf(stderr,"ascii: %02x\n",src[0]);
-      if( src[0]!='\e' || src+2>=src_end || src[1]!='$' )
-      { // ʸʤ
+      /*fprintf(stderr,"ascii: %02x\n",src[0]); */
+      if( src[0]!='\x1b' || src+2>=src_end || src[1]!='$' )
+      { /* ʸʤ */
 	SV_Buf_append_ch(&result,*src);
 	++src;
 	continue;
       }
-      //fprint(stderr,"detect j-sky emoji-start escape\n");
-      // E_JSKY_1
+      /* warn("detect j-sky emoji-start escape\n"); */
+      /* E_JSKY_1 */
       if( src[2]=='E' || src[2]=='F' || src[2]=='G' )
       {
 	j1 = (src[2]-'E')<<8;
@@ -200,7 +200,7 @@ xs_sjis_jsky2_utf8(SV* sv_str)
       {
 	j1 = 0;
 	table = NULL;
-	//fprintf(stderr,"first char is invalid");
+	/* warn("first char is invalid"); */
 	SV_Buf_append_ch(&result,*src);
 	++src;
 	continue;
@@ -208,7 +208,7 @@ xs_sjis_jsky2_utf8(SV* sv_str)
 
       begin = src;
       src += 3;
-      // E_JSKY_2
+      /* E_JSKY_2 */
       while( src+1<src_end )
       {
 	if( '!'<=src[0] && src[0]<='z' )
@@ -220,7 +220,7 @@ xs_sjis_jsky2_utf8(SV* sv_str)
       }
       if( src[0]!=0x0f )
       {
-	//fprintf(stderr,"invalid\n");
+	/* warn("invalid\n"); */
 	src = begin;
 	SV_Buf_append_ch(&result,*src);
 	++src;
@@ -229,50 +229,50 @@ xs_sjis_jsky2_utf8(SV* sv_str)
       ++src;
       for( ptr = begin+3; ptr<src-1; ++ptr )
       {
-	//fprintf(stderr," <%c%c:%04x>\n",begin[2],*ptr,j1+*ptr);
-	//fprintf(stderr,"   => %04x\n",g_ej2u2_table[j1+*ptr]);
+	/*fprintf(stderr," <%c%c:%04x>\n",begin[2],*ptr,j1+*ptr); */
+	/*fprintf(stderr,"   => %04x\n",g_ej2u2_table[j1+*ptr]); */
 	const unsigned char* str = (unsigned char*)&table[j1+*ptr];
-	//fprintf(stderr,"   len: %d\n",str[3]?4:strlen((char*)str));
+	/*fprintf(stderr,"   len: %d\n",str[3]?4:strlen((char*)str)); */
 	SV_Buf_append_str(&result,str,str[3]?4:strlen((char*)str));
       }
-      //fprintf(stderr,"j-sky string done.\n");
+      /*fprintf(stderr,"j-sky string done.\n"); */
       continue;
     }else if( 0xa1<=src[0] && src[0]<=0xdf )
-    { // Ⱦѥ
-      //fprintf(stderr,"kana": %02x\n",src[0]);
+    { /* Ⱦѥ */
+      /*fprintf(stderr,"kana": %02x\n",src[0]); */
       ptr = (unsigned char*)&g_s2u_table[src[0]];
       ++src;
     }else if( ((0x81<=src[0] && src[0]<=0x9f) || (0xe0<=src[0] && src[0]<=0xfc) )
 	      && (0x40<=src[1] && src[1]<=0xfc && src[1]!=0x7f) )
-    { // 2Хʸ
+    { /* 2Хʸ */
       register const unsigned short sjis = ntohs(*(unsigned short*)src);
-      //fprintf(stderr,"sjis: %04x\n",sjis);
+      /*fprintf(stderr,"sjis: %04x\n",sjis); */
       ptr = (unsigned char*)&g_s2u_table[sjis];
       src += 2;
     }else
-    { // 
-      //fprintf(stderr,"unknown: %02x\n",src[0]);
+    { /*  */
+      /*fprintf(stderr,"unknown: %02x\n",src[0]); */
       SV_Buf_append_ch(&result,'?');
       ++src;
       continue;
     }
 
-    //fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]);
+    /*fprintf(stderr,"utf8-char : %02x %02x %02x %02x\n",ptr[0],ptr[1],ptr[2],ptr[3]); */
     if( ptr[3] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",4);
+      /*fprintf(stderr,"utf8-len: [%d]\n",4); */
       SV_Buf_append_ch4(&result,*(int*)ptr);
     }else if( ptr[2] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",3);
+      /*fprintf(stderr,"utf8-len: [%d]\n",3); */
       SV_Buf_append_ch3(&result,*(int*)ptr);
     }else if( ptr[1] )
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",2);
+      /*fprintf(stderr,"utf8-len: [%d]\n",2); */
       SV_Buf_append_ch2(&result,*(short*)ptr);
     }else
     {
-      //fprintf(stderr,"utf8-len: [%d]\n",1);
+      /*fprintf(stderr,"utf8-len: [%d]\n",1); */
       SV_Buf_append_ch(&result,*ptr);
     }
   }
@@ -318,7 +318,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
     
     if( *src<=0x7f )
     {
-      // ASCIIϤޤȤɲá
+      /* ASCIIϤޤȤɲá */
       int len = 1;
       while( src+len<src_end && src[len]<=0x7f )
       {
@@ -328,8 +328,8 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       src+=len;
       continue;
     }
-    // utf8ucsѴ
-    // utf8ΣʸĹå
+    /* utf8ucsѴ */
+    /* utf8ΣʸĹå */
     if( 0xc0<=*src && *src<=0xdf )
     {
       utf8_len = 2;
@@ -351,7 +351,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       ++src;
       continue;
     }
-    // Ĺ­Ƥ뤫å
+    /* Ĺ­Ƥ뤫å */
     if( src+utf8_len-1>=src_end )
     {
       ECHO_U2EJ((stderr,"  no enough buffer, here is %d, need %d\n",src_end-src,utf8_len));
@@ -359,7 +359,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       ++src;
       continue;
     }
-    // ХܰʹߤʸϰϤǧ
+    /* ХܰʹߤʸϰϤǧ */
     succ = true;
     for( i=1; i<utf8_len; ++i )
     {
@@ -376,7 +376,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       ++src;
       continue;
     }
-    // utf8ucsΥɤ򻻽
+    /* utf8ucsΥɤ򻻽 */
     ECHO_U2EJ((stderr,"utf8-charlen: [%d]\n",utf8_len));
     switch(utf8_len)
     {
@@ -412,45 +412,45 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       }
     default:
       {
-        // NOT REACH HERE
+        /* NOT REACH HERE */
 	ECHO_U2EJ((stderr,"invalid utf8-length: %d\n",utf8_len));
 	ucs = '?';
       }
     }
 
     if( 0x0f0000<=ucs && ucs<=0x0fffff )
-    { // ΰ
+    { /* ΰ */
       const unsigned char* sjis;
       assert(utf8_len>=4);
       if( ucs<0x0ff000 )
-      { // Τʤΰ
+      { /* Τʤΰ */
         SV_Buf_append_ch(&result,'?');
 	src += utf8_len;
 	continue;
       }
-      // ʸȽ(j-sky)
+      /* ʸȽ(j-sky) */
       sjis = &g_eu2j1_table[(ucs - 0x0ff000)*5];
-      //fprintf(stderr,"  emoji: %02x %02x %02x %02x %02x\n",
-      //	  sjis[0],sjis[1],sjis[2],sjis[3],sjis[4]);
+      /*fprintf(stderr,"  emoji: %02x %02x %02x %02x %02x\n", */
+      /*	  sjis[0],sjis[1],sjis[2],sjis[3],sjis[4]); */
       if( sjis[4]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch5(&result,sjis);
       }else if( sjis[3]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	assert("not reach here" && 0);
 	SV_Buf_append_ch4(&result,*(const int*)(sjis));
       }else if( sjis[2]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	assert("not reach here" && 0);
 	SV_Buf_append_ch3(&result,*(const int*)(sjis));
       }else if( sjis[1]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch2(&result,*(const unsigned short*)(sjis));
       }else if( sjis[0]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch(&result,*sjis);
       }else
-      { // ޥåԥ󥰤ʤ
+      { /* ޥåԥ󥰤ʤ */
         SV_Buf_append_ch(&result,'?');
       }
       src += utf8_len;
@@ -458,19 +458,19 @@ xs_utf8_sjis_jsky1(SV* sv_str)
     }
 
     if( ucs & ~0xFFFF )
-    { // ucs2ϰϳ (ucs4ϰ)
+    { /* ucs2ϰϳ (ucs4ϰ) */
       SV_Buf_append_ch(&result,'?');
       src += utf8_len;
       continue;
     }
     
-    // ucs => sjis
+    /* ucs => sjis */
     ECHO_U2EJ((stderr,"ucs2 [%04x]\n",ucs));
-    //const unsigned short sjis = g_u2s_table[ucs];
+    /*const unsigned short sjis = g_u2s_table[ucs]; */
     ECHO_U2EJ((stderr,"sjis [%04x]\n",ntohs(sjis) ));
     
     if( g_u2s_table[ucs] || !ucs )
-    { // бʸucs=='\0'λ
+    { /* бʸucs=='\0'λ */
       if( g_u2s_table[ucs] & 0xff00 )
       {
 	SV_Buf_append_ch2(&result,g_u2s_table[ucs]);
@@ -486,7 +486,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
       SV_Buf_append_ch(&result,'?');
     }
     src += utf8_len;
-    //bin_dump("now",dst_begin,dst-dst_begin);
+    /*bin_dump("now",dst_begin,dst-dst_begin); */
   } /* for */
 
   ON_U2EJ( bin_dump("out",result.getBegin(),result.getLength()) );
@@ -494,7 +494,7 @@ xs_utf8_sjis_jsky1(SV* sv_str)
   sv_2mortal(SV_Buf_getSv(&result));
 
   {
-  // packing J-SKY emoji escapes
+  /* packing J-SKY emoji escapes */
   SV_Buf pack;
   unsigned char* ptr;
   unsigned char tmpl[5] = { '\x1b','$',0,0,'\x0f',};
@@ -506,27 +506,27 @@ xs_utf8_sjis_jsky1(SV* sv_str)
   for( ; src+5*2-1<src_end; ++src )
   {
     unsigned char ch1;
-    // E_JSKY_START  "\e\$",
+    /* E_JSKY_START  "\x1b\$", */
     if( src[0]!='\x1b' ) continue;
     if( src[1]!='$' ) continue;
-    // E_JSKY1   '[EFG]',
-    //fprintf(stderr,"  found emoji-start\n");
+    /* E_JSKY1   '[EFG]', */
+    /*fprintf(stderr,"  found emoji-start\n"); */
     if( src[2]!='E' && src[2]!='F' && src[2]!='G' )
     {
-      //fprintf(stderr,"  invalid ch1 [%x:%02x]\n",src[2],src[2]);
+      /*fprintf(stderr,"  invalid ch1 [%x:%02x]\n",src[2],src[2]); */
       continue;
     }
     ch1 = src[2];
-    // E_JSKY2    '[\!-\;\=-z\xbc]',
+    /* E_JSKY2    '[\!-\;\=-z\xbc]', */
     if( src[3]<'!' || 'z'<src[3] )
     {
-      //fprintf(stderr,"  invalid ch2 [%02x]\n",src[3]);
+      /*fprintf(stderr,"  invalid ch2 [%02x]\n",src[3]); */
       continue;
     }
-    // E_JSKY_END    "\x0f",
+    /* E_JSKY_END    "\x0f", */
     if( src[4]!='\x0f' ) continue;
 
-    //fprintf(stderr,"  found first emoji [%02x:%c]\n",ch1,ch1);
+    /*fprintf(stderr,"  found first emoji [%02x:%c]\n",ch1,ch1); */
     src += 5;
     SV_Buf_append_str(&pack,ptr,(src-1)-ptr);
     tmpl[2] = ch1;
@@ -534,15 +534,15 @@ xs_utf8_sjis_jsky1(SV* sv_str)
     {
       tmpl[3] = src[3];
       if( memcmp(src,tmpl,5)!=0 ) break;
-      //fprintf(stderr,"  packing...[%02x]\n",src[3]);
+      /*fprintf(stderr,"  packing...[%02x]\n",src[3]); */
       SV_Buf_append_ch(&pack,src[3]);
     }
-    //fprintf(stderr,"  pack done.\n");
+    /*fprintf(stderr,"  pack done.\n"); */
     SV_Buf_append_ch(&pack,'\x0f');
     ptr = src;
   }
-  //fprintf(stderr,"  pack complete.\n");
-  //fprintf(stderr,"  append len %0d\n",src_end-ptr);
+  /*fprintf(stderr,"  pack complete.\n"); */
+  /*fprintf(stderr,"  append len %0d\n",src_end-ptr); */
   if( ptr!=src_end )
   {
     SV_Buf_append_str(&pack,ptr,src_end-ptr);
@@ -590,7 +590,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
     
     if( *src<=0x7f )
     {
-      // ASCIIϤޤȤɲá
+      /* ASCIIϤޤȤɲá */
       int len = 1;
       while( src+len<src_end && src[len]<=0x7f )
       {
@@ -600,8 +600,8 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       src+=len;
       continue;
     }
-    // utf8ucsѴ
-    // utf8ΣʸĹå
+    /* utf8ucsѴ */
+    /* utf8ΣʸĹå */
     if( 0xc0<=*src && *src<=0xdf )
     {
       utf8_len = 2;
@@ -623,7 +623,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       ++src;
       continue;
     }
-    // Ĺ­Ƥ뤫å
+    /* Ĺ­Ƥ뤫å */
     if( src+utf8_len-1>=src_end )
     {
       ECHO_U2EJ((stderr,"  no enough buffer, here is %d, need %d\n",src_end-src,utf8_len));
@@ -631,7 +631,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       ++src;
       continue;
     }
-    // ХܰʹߤʸϰϤǧ
+    /* ХܰʹߤʸϰϤǧ */
     succ = true;
     for( i=1; i<utf8_len; ++i )
     {
@@ -648,7 +648,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       ++src;
       continue;
     }
-    // utf8ucsΥɤ򻻽
+    /* utf8ucsΥɤ򻻽 */
     ECHO_U2EJ((stderr,"utf8-charlen: [%d]\n",utf8_len));
     switch(utf8_len)
     {
@@ -684,45 +684,45 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       }
     default:
       {
-        // NOT REACH HERE
+        /* NOT REACH HERE */
 	ECHO_U2EJ((stderr,"invalid utf8-length: %d\n",utf8_len));
 	ucs = '?';
       }
     }
 
     if( 0x0f0000<=ucs && ucs<=0x0fffff )
-    { // ΰ
+    { /* ΰ */
       const unsigned char* sjis;
       assert(utf8_len>=4);
       if( ucs<0x0ff000 )
-      { // Τʤΰ
+      { /* Τʤΰ */
         SV_Buf_append_ch(&result,'?');
 	src += utf8_len;
 	continue;
       }
-      // ʸȽ(j-sky)
+      /* ʸȽ(j-sky) */
       sjis = &g_eu2j2_table[(ucs - 0x0ff000)*5];
-      //fprintf(stderr,"  emoji: %02x %02x %02x %02x %02x\n",
-      //	  sjis[0],sjis[1],sjis[2],sjis[3],sjis[4]);
+      /*fprintf(stderr,"  emoji: %02x %02x %02x %02x %02x\n", */
+      /*	  sjis[0],sjis[1],sjis[2],sjis[3],sjis[4]); */
       if( sjis[4]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch5(&result,sjis);
       }else if( sjis[3]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	assert("not reach here" && 0);
 	SV_Buf_append_ch4(&result,*(const int*)(sjis));
       }else if( sjis[2]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	assert("not reach here" && 0);
 	SV_Buf_append_ch3(&result,*(const int*)(sjis));
       }else if( sjis[1]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch2(&result,*(const unsigned short*)(sjis));
       }else if( sjis[0]!=0 )
-      { // Хʸ.
+      { /* Хʸ. */
 	SV_Buf_append_ch(&result,*sjis);
       }else
-      { // ޥåԥ󥰤ʤ
+      { /* ޥåԥ󥰤ʤ */
         SV_Buf_append_ch(&result,'?');
       }
       src += utf8_len;
@@ -730,19 +730,19 @@ xs_utf8_sjis_jsky2(SV* sv_str)
     }
 
     if( ucs & ~0xFFFF )
-    { // ucs2ϰϳ (ucs4ϰ)
+    { /* ucs2ϰϳ (ucs4ϰ) */
       SV_Buf_append_ch(&result,'?');
       src += utf8_len;
       continue;
     }
     
-    // ucs => sjis
+    /* ucs => sjis */
     ECHO_U2EJ((stderr,"ucs2 [%04x]\n",ucs));
-    //const unsigned short sjis = g_u2s_table[ucs];
+    /*const unsigned short sjis = g_u2s_table[ucs]; */
     ECHO_U2EJ((stderr,"sjis [%04x]\n",ntohs(sjis) ));
     
     if( g_u2s_table[ucs] || !ucs )
-    { // бʸucs=='\0'λ
+    { /* бʸucs=='\0'λ */
       if( g_u2s_table[ucs] & 0xff00 )
       {
 	SV_Buf_append_ch2(&result,g_u2s_table[ucs]);
@@ -758,7 +758,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
       SV_Buf_append_ch(&result,'?');
     }
     src += utf8_len;
-    //bin_dump("now",dst_begin,dst-dst_begin);
+    /*bin_dump("now",dst_begin,dst-dst_begin); */
   } /* for */
 
   ON_U2EJ( bin_dump("out",result.getBegin(),result.getLength()) );
@@ -766,7 +766,7 @@ xs_utf8_sjis_jsky2(SV* sv_str)
   sv_2mortal(SV_Buf_getSv(&result));
 
   {
-  // packing J-SKY emoji escapes
+  /* packing J-SKY emoji escapes */
   SV_Buf pack;
   unsigned char* ptr;
   
@@ -778,28 +778,28 @@ xs_utf8_sjis_jsky2(SV* sv_str)
   {
     unsigned char ch1;
     unsigned char tmpl[5] = { '\x1b','$',0,0,'\x0f',};
-    // E_JSKY_START  "\e\$",
+    /* E_JSKY_START  "\x1b\$", */
     if( src[0]!='\x1b' ) continue;
     if( src[1]!='$' ) continue;
-    // E_JSKY1   '[EFG]',
-    //fprintf(stderr,"  found emoji-start\n");
+    /* E_JSKY1   '[EFG]', */
+    /*fprintf(stderr,"  found emoji-start\n"); */
     if( src[2]!='E' && src[2]!='F' && src[2]!='G' 
 	&& src[2]!='O' && src[2]!='P' && src[2]!='Q' )
     {
-      //fprintf(stderr,"  invalid ch1 [%x:%02x]\n",src[2],src[2]);
+      /*fprintf(stderr,"  invalid ch1 [%x:%02x]\n",src[2],src[2]); */
       continue;
     }
     ch1 = src[2];
-    // E_JSKY2    '[\!-\;\=-z\xbc]',
+    /* E_JSKY2    '[\!-\;\=-z\xbc]', */
     if( src[3]<'!' || 'z'<src[3] )
     {
-      //fprintf(stderr,"  invalid ch2 [%02x]\n",src[3]);
+      /*fprintf(stderr,"  invalid ch2 [%02x]\n",src[3]); */
       continue;
     }
-    // E_JSKY_END    "\x0f",
+    /* E_JSKY_END    "\x0f", */
     if( src[4]!='\x0f' ) continue;
 
-    //fprintf(stderr,"  found first emoji [%02x:%c]\n",ch1,ch1);
+    /*fprintf(stderr,"  found first emoji [%02x:%c]\n",ch1,ch1); */
     src += 5;
     SV_Buf_append_str(&pack,ptr,(src-1)-ptr);
     tmpl[2] = ch1;
@@ -807,15 +807,15 @@ xs_utf8_sjis_jsky2(SV* sv_str)
     {
       tmpl[3] = src[3];
       if( memcmp(src,tmpl,5)!=0 ) break;
-      //fprintf(stderr,"  packing...[%02x]\n",src[3]);
+      /*fprintf(stderr,"  packing...[%02x]\n",src[3]); */
       SV_Buf_append_ch(&pack,src[3]);
     }
-    //fprintf(stderr,"  pack done.\n");
+    /*fprintf(stderr,"  pack done.\n"); */
     SV_Buf_append_ch(&pack,'\x0f');
     ptr = src;
   }
-  //fprintf(stderr,"  pack complete.\n");
-  //fprintf(stderr,"  append len %0d\n",src_end-ptr);
+  /*fprintf(stderr,"  pack complete.\n"); */
+  /*fprintf(stderr,"  append len %0d\n",src_end-ptr); */
   if( ptr!=src_end )
   {
     SV_Buf_append_str(&pack,ptr,src_end-ptr);
